@@ -1,3 +1,3 @@
-from file_ripper.fileripper import rip_file, rip_files
+from file_ripper.fileripper import rip_file, rip_files, find_and_rip_files
 from file_ripper.filedefinition import FileDefinition, FieldDefinition
 import file_ripper.fileconstants as file_constants
